@@ -119,7 +119,11 @@ def upload_nexus_maven():
     
     params = (('repository', __main__.repository_name),)
    
-    finalpath = __main__.work_directory + '/' + __main__.artifact_name
+    #finalpath = __main__.work_directory + '/' + __main__.artifact_name
+    finalpath = __main__.os.path.join(__main__.work_directory, __main__.artifact_name)
+    
+    if __main__.artifact_name2:
+        finalpath2 = __main__.os.path.join(__main__.work_directory, __main__.artifact_name2)
     
     if ('tar.gz' in __main__.artifact_name):
         pass
@@ -172,6 +176,16 @@ def upload_nexus_maven():
         'maven2.asset1.extension': (None, extension),
         'maven2.generate-pom': (None, True) 
     }
+    
+    if __main__.artifact_name2:
+        fn, fe = __main__.os.path.splitext(__main__.artifact_name2)
+        try:
+            files['maven2.asset2'] = ( __main__.artifact_name2, open(finalpath2, 'rb'))
+        except FileNotFoundError:
+            print("ERROR: File not found : ",__main__.artifact_name2)
+            return __main__.sys.exit(2)
+        files['maven2.asset2.classifier'] = (None, fn)
+        files['maven2.asset2.extension'] = (None, fe[1:])
 
     response = __main__.requests.post(url=__main__.repository_full_url, params=params, files=files, auth=__main__.auth, proxies=__main__.proxies, verify=False)
     if __main__.debug == 1:
@@ -180,10 +194,10 @@ def upload_nexus_maven():
         print("Nexus Upload successful")
         return __main__.sys.exit(0)
     elif response.status_code == 400 and ("release" in __main__.repository_name or "staging" in __main__.repository_name):
-        print("Nexus Upload failed. Please modify version number")
+        print("Nexus Upload failed. {}".format(response.json()[0].get('message')))
         return __main__.sys.exit(1)
     else:
-        print("Nexus Upload failed")
+        print("Nexus Upload failed. {}".format(response.json()[0].get('message')))
         print("Status code: ", response.status_code)
      
         return __main__.sys.exit(1)
