@@ -58,9 +58,21 @@ def commit_push_changes(message):
         print("ERROR: Private token missing. Please add PRIVATE_TOKEN to Environment variables")
         __main__.os.sys.exit(1)
     
-    auth = "//" + __main__.os.environ.get('GITLAB_USER_LOGIN') + ":" + __main__.os.environ.get('PRIVATE_TOKEN') + "@"
+    ci_user = ''
+    
+    if __main__.os.environ.get('GITLAB_USER_LOGIN'):
+        ci_user = __main__.os.environ.get('GITLAB_USER_LOGIN')
+    
+    if __main__.os.environ.get('GITHUB_REPOSITORY_OWNER'):
+        ci_user = __main__.os.environ.get('GITHUB_REPOSITORY_OWNER')
+        
+    if __main__.os.environ.get('GITHUB_OWNER'):
+        ci_user = __main__.os.environ.get('GITHUB_REPOSITORY_OWNER')
+        
+    auth = "//" + ci_user + ":" + __main__.os.environ.get('PRIVATE_TOKEN') + "@"
 
     repository_url = __main__.os.environ.get("CI_REPOSITORY_URL")
+    #git config --get remote.origin.url
     ## CI_PROJECT_URL
         
     ## Repository url with token
